@@ -18,27 +18,34 @@
 #'
 #' @examples
 #' # U Island example region
-#' coordinates <- data.frame(x = rep(seq(177.01, 177.05, 0.01), 5),
-#'                           y = rep(seq(-18.01, -18.05, -0.01), each = 5))
+#' coordinates <- data.frame(
+#'   x = rep(seq(177.01, 177.05, 0.01), 5),
+#'   y = rep(seq(-18.01, -18.05, -0.01), each = 5)
+#' )
 #' template_raster <- Region$new(coordinates = coordinates)$region_raster # full extent
 #' template_raster[][-c(7, 9, 12, 14, 17:19)] <- NA # make U Island
 #' region <- Region$new(template_raster = template_raster)
-#' raster::plot(region$region_raster, main = "Example region (indices)",
-#'              xlab = "Longitude (degrees)", ylab = "Latitude (degrees)",
-#'              colNA = "blue")
+#' raster::plot(region$region_raster,
+#'   main = "Example region (indices)",
+#'   xlab = "Longitude (degrees)", ylab = "Latitude (degrees)",
+#'   colNA = "blue"
+#' )
 #'
 #' # Distance-based dispersal generator
-#' dispersal_gen <- DispersalGenerator$new(region = region,
-#'                                         dispersal_max_distance = 3000, # in m
-#'                                         inputs = c("dispersal_p", "dispersal_b"),
-#'                                         decimals = 5)
+#' dispersal_gen <- DispersalGenerator$new(
+#'   region = region,
+#'   dispersal_max_distance = 3000, # in m
+#'   inputs = c("dispersal_p", "dispersal_b"),
+#'   decimals = 5
+#' )
 #' dispersal_gen$calculate_distance_data() # pre-calculate
-#' dispersal_gen$generate(input_values = list(dispersal_p = 0.5,
-#'                                            dispersal_b = 700))
+#' dispersal_gen$generate(input_values = list(
+#'   dispersal_p = 0.5,
+#'   dispersal_b = 700
+#' ))
 #'
 #' @importFrom R6 R6Class
-#' @importFrom geosphere distm
-#' @importFrom geosphere distGeo
+#' @importFrom fossil earth.dist
 #' @import raster
 #' @include Generator.R
 #' @include DispersalTemplate.R
@@ -89,10 +96,14 @@ DispersalGenerator <- R6Class("DispersalGenerator",
                           attribute_aliases = NULL, ...) {
       if (is.null(generative_template)) { # when new object
         self$generative_template <- DispersalTemplate$new()
-        attribute_aliases <- c(attribute_aliases, # Append default aliases
-                               list(proportion = "dispersal_proportion", dispersal_p = "dispersal_proportion", p = "dispersal_proportion",
-                                    breadth = "dispersal_breadth", dispersal_b = "dispersal_breadth", b = "dispersal_breadth",
-                                    max_distance = "dispersal_max_distance", dispersal_r = "dispersal_max_distance", r = "dispersal_max_distance"))
+        attribute_aliases <- c(
+          attribute_aliases, # Append default aliases
+          list(
+            proportion = "dispersal_proportion", dispersal_p = "dispersal_proportion", p = "dispersal_proportion",
+            breadth = "dispersal_breadth", dispersal_b = "dispersal_breadth", b = "dispersal_breadth",
+            max_distance = "dispersal_max_distance", dispersal_r = "dispersal_max_distance", r = "dispersal_max_distance"
+          )
+        )
         param_names <- names(c(list(...), list(...)$params))
         if (!("description" %in% param_names)) {
           self$description <- "dispersal"
@@ -115,9 +126,11 @@ DispersalGenerator <- R6Class("DispersalGenerator",
       if (is.null(generative_requirements)) {
         generative_requirements <- list(dispersal_data = "default")
       }
-      super$initialize(generative_template = generative_template,
-                       generative_requirements = generative_requirements,
-                       attribute_aliases = attribute_aliases, ...)
+      super$initialize(
+        generative_template = generative_template,
+        generative_requirements = generative_requirements,
+        attribute_aliases = attribute_aliases, ...
+      )
       if (!is.null(dispersal_friction)) {
         self$dispersal_friction <- dispersal_friction
       }
@@ -131,17 +144,17 @@ DispersalGenerator <- R6Class("DispersalGenerator",
       if (is.list(satisfied)) {
         function_params <- c("dispersal_proportion", "dispersal_breadth", "dispersal_max_distance")
         function_data_required <- (length(self$get_attributes(function_params)) +
-                                     length(which(self$get_attribute_aliases(function_params) %in% self$inputs)) < 3)
+          length(which(self$get_attribute_aliases(function_params) %in% self$inputs)) < 3)
         dispersal_matrix_default <- ("dispersal_matrix" %in% names(satisfied) && self$generative_requirements$dispersal_matrix == "default")
         if (dispersal_matrix_default) {
           satisfied$dispersal_matrix <- (!is.null(self$coordinates) && !is.null(self$distance_classes) &&
-                                           (!is.null(self$dispersal_function_data) || !function_data_required) &&
-                                           !is.null(self$distance_data))
+            (!is.null(self$dispersal_function_data) || !function_data_required) &&
+            !is.null(self$distance_data))
         }
         dispersal_data_default <- ("dispersal_data" %in% names(satisfied) && self$generative_requirements$dispersal_data == "default")
         if (dispersal_data_default) {
           satisfied$dispersal_data <- (!is.null(self$coordinates) && !is.null(self$distance_classes) &&
-                                         (!is.null(self$dispersal_function_data) || !function_data_required))
+            (!is.null(self$dispersal_function_data) || !function_data_required))
           satisfied$dispersal_data <- (satisfied$dispersal_data && !is.null(self$distance_data))
         }
         # Add any attributes that are missing (for error message)
@@ -187,13 +200,13 @@ DispersalGenerator <- R6Class("DispersalGenerator",
           stop("Distance matrix calculation requires the region to be defined with coordinates or a raster first", call. = FALSE)
         }
         if (!self$region$use_raster || (is.logical(use_longlat) && use_longlat) ||
-            length(grep("longlat", as.character(raster::crs(self$region$region_raster)), fixed = TRUE)) > 0) {
-          return(distm(coordinates, coordinates, fun = distGeo)/self$distance_scale)
+          length(grep("longlat", as.character(raster::crs(self$region$region_raster)), fixed = TRUE)) > 0) {
+          return(earth.dist(coordinates, dist = FALSE)*1000 / self$distance_scale)
         } else { # assume coordinates in meters
           if (is.na(raster::crs(self$region$region_raster))) {
             warning("No coordinate reference system (CRS) specified: assuming coordinates are in meters", call. = FALSE)
           }
-          return(as.matrix(stats::dist(coordinates))/self$distance_scale)
+          return(as.matrix(stats::dist(coordinates)) / self$distance_scale)
         }
       } else {
         stop("Distance matrix calculation requires region/coordinates to be set first", call. = FALSE)
@@ -205,7 +218,6 @@ DispersalGenerator <- R6Class("DispersalGenerator",
     #' @param distance_matrix Optional pre-calculated matrix with distances between population cells (population rows by population columns).
     #' @param ... Parameters passed via a \emph{params} list or individually.
     calculate_distance_data = function(distance_matrix = NULL, ...) {
-
       # Set attributes
       self$distance_data <- NULL
       if (length(list(...))) {
@@ -231,7 +243,7 @@ DispersalGenerator <- R6Class("DispersalGenerator",
 
       # Calculate the indices of distances within the maximum dispersal range
       distance_data <- which(distance_matrix > 0 & distance_matrix <= max(self$distance_classes), arr.ind = TRUE)
-      distance_data <- distance_data[order(distance_data[, 2], distance_data[, 1]),]
+      distance_data <- distance_data[order(distance_data[, 2], distance_data[, 1]), ]
       colnames(distance_data) <- c("target_pop", "source_pop")
       distances_within_range <- distance_matrix[distance_data]
       distance_matrix <- NULL # release from memory
@@ -246,13 +258,13 @@ DispersalGenerator <- R6Class("DispersalGenerator",
         distance_multipliers <- self$dispersal_friction$calculate_distance_multipliers(distance_data)
         if (length(distance_multipliers) == 1) { # apply multipliers and update distances
           if (!is.null(self$dispersal_friction$write_to_dir)) {
-            distances_within_range <- distances_within_range*readRDS(distance_multipliers[[1]])
+            distances_within_range <- distances_within_range * readRDS(distance_multipliers[[1]])
           } else {
-            distances_within_range <- distances_within_range*distance_multipliers[[1]]
+            distances_within_range <- distances_within_range * distance_multipliers[[1]]
           }
           out_of_range <- which(distances_within_range > max(self$distance_classes))
           distances_within_range <- distances_within_range[-out_of_range]
-          distance_data <- distance_data[-out_of_range,]
+          distance_data <- distance_data[-out_of_range, ]
         }
       }
 
@@ -262,7 +274,7 @@ DispersalGenerator <- R6Class("DispersalGenerator",
       dispersal_rows <- tabulate(distance_data$source_pop, nbins = populations)
       compact_rows <- max(dispersal_rows)
       compact_matrix <- array(1:compact_rows, c(compact_rows, populations))
-      compact_matrix <- compact_matrix*(compact_matrix <= matrix(dispersal_rows, nrow = compact_rows, ncol = populations, byrow = TRUE))
+      compact_matrix <- compact_matrix * (compact_matrix <= matrix(dispersal_rows, nrow = compact_rows, ncol = populations, byrow = TRUE))
       # Map the row of each compact matrix to the original target population
       distance_data$compact_row <- which(compact_matrix > 0, arr.ind = TRUE, useNames = FALSE)[, 1]
 
@@ -277,17 +289,16 @@ DispersalGenerator <- R6Class("DispersalGenerator",
         for (i in 1:length(distance_multipliers)) {
           previous_distance_classes <- current_distance_classes
           if (!is.null(self$dispersal_friction$write_to_dir)) {
-            current_distance_classes <- as.numeric(cut(distances_within_range*readRDS(distance_multipliers[[i]]), breaks = c(0, self$distance_classes, Inf)))
+            current_distance_classes <- as.numeric(cut(distances_within_range * readRDS(distance_multipliers[[i]]), breaks = c(0, self$distance_classes, Inf)))
           } else {
-            current_distance_classes <- as.numeric(cut(distances_within_range*distance_multipliers[[i]], breaks = c(0, self$distance_classes, Inf)))
+            current_distance_classes <- as.numeric(cut(distances_within_range * distance_multipliers[[i]], breaks = c(0, self$distance_classes, Inf)))
           }
           changed_indices <- which(current_distance_classes != previous_distance_classes)
-          sequential_distance_data[[i]] <- data.frame(distance_data[changed_indices,], distance_class = current_distance_classes[changed_indices])
+          sequential_distance_data[[i]] <- data.frame(distance_data[changed_indices, ], distance_class = current_distance_classes[changed_indices])
         }
         distance_multipliers <- NULL # release from memory
         self$distance_data$changes <- sequential_distance_data
       }
-
     },
 
     #' @description
@@ -295,7 +306,6 @@ DispersalGenerator <- R6Class("DispersalGenerator",
     #' @param type Optional type selector (\emph{"data"} or \emph{"matrix"}) to determine whether to calculate a dispersal matrix or data frame (default).
     #' @return Returns character string message when calculation prerequisites are not met (for simulation logging).
     calculate_dispersals = function(type = "data") {
-
       # Ensure distance data are calculated
       if (is.null(self$distance_data)) {
         return("Dispersal distance data needs to be calculated before dispersals can be generated")
@@ -303,9 +313,8 @@ DispersalGenerator <- R6Class("DispersalGenerator",
 
       # Calculate dispersals using distance data and sampled dispersal function parameters
       if (!is.null(self$dispersal_proportion) && !is.null(self$dispersal_breadth) && !is.null(self$dispersal_max_distance)) {
-
         # Calculate dispersal rates for each distance class (discrete values)
-        dispersal_rate_classes <- c(ifelse(self$distance_classes <= self$dispersal_max_distance, self$dispersal_proportion*exp(-1*self$distance_classes/self$dispersal_breadth), 0), 0)
+        dispersal_rate_classes <- c(ifelse(self$distance_classes <= self$dispersal_max_distance, self$dispersal_proportion * exp(-1 * self$distance_classes / self$dispersal_breadth), 0), 0)
 
         # Select base (non-friction) data for non-zero dispersal classes
         nonzero_base_data <- self$distance_data$base[which(self$distance_data$base$distance_class <= length(which(dispersal_rate_classes > 0))), ]
@@ -318,17 +327,17 @@ DispersalGenerator <- R6Class("DispersalGenerator",
         compact_matrix[compact_dispersal_indices] <- dispersal_rate_classes[nonzero_base_data$distance_class]
 
         # Calculate multipliers to set the total proportion migrating from each cell (without friction) to <= p
-        multipliers <- self$dispersal_proportion/.colSums(compact_matrix, m = base_compact_rows, n = populations)
+        multipliers <- self$dispersal_proportion / .colSums(compact_matrix, m = base_compact_rows, n = populations)
         multipliers[which(!is.finite(multipliers) | multipliers > 1)] <- 1
 
         # Apply multipliers to the base compact dispersal matrix
-        compact_matrix <- compact_matrix*matrix(multipliers, nrow = base_compact_rows, ncol = populations, byrow = TRUE)
+        compact_matrix <- compact_matrix * matrix(multipliers, nrow = base_compact_rows, ncol = populations, byrow = TRUE)
 
         # Extract dispersal rates and round when required (then update non-zero base/non-friction dispersal data)
         nonzero_base_data$dispersal_rate <- compact_matrix[compact_dispersal_indices]
         if (!is.null(self$decimals)) {
           nonzero_base_data$dispersal_rate <- round(nonzero_base_data$dispersal_rate, self$decimals)
-          nonzero_base_data <- nonzero_base_data[which(nonzero_base_data$dispersal_rate > 0),]
+          nonzero_base_data <- nonzero_base_data[which(nonzero_base_data$dispersal_rate > 0), ]
           compact_dispersal_indices <- as.matrix(nonzero_base_data[, c("compact_row", "source_pop")])
         }
 
@@ -338,11 +347,11 @@ DispersalGenerator <- R6Class("DispersalGenerator",
         nonzero_compact_rows <- max(dispersal_rows, dispersal_cols)
         if (nonzero_compact_rows) {
           compact_emigrant_matrix <- array(1:nonzero_compact_rows, c(nonzero_compact_rows, populations))
-          compact_immigrant_matrix <- compact_emigrant_matrix*(compact_emigrant_matrix <= matrix(dispersal_cols, nrow = nonzero_compact_rows, ncol = populations, byrow = TRUE))
-          compact_emigrant_matrix <- compact_emigrant_matrix*(compact_emigrant_matrix <= matrix(dispersal_rows, nrow = nonzero_compact_rows, ncol = populations, byrow = TRUE))
+          compact_immigrant_matrix <- compact_emigrant_matrix * (compact_emigrant_matrix <= matrix(dispersal_cols, nrow = nonzero_compact_rows, ncol = populations, byrow = TRUE))
+          compact_emigrant_matrix <- compact_emigrant_matrix * (compact_emigrant_matrix <= matrix(dispersal_rows, nrow = nonzero_compact_rows, ncol = populations, byrow = TRUE))
           # Map the row of each compact matrix to the original target (for emigrants) or source (for immigrants) populations
-          nonzero_base_data$emigrant_row <- which(compact_emigrant_matrix > 0, arr.ind = TRUE, useNames = FALSE)[,1]
-          nonzero_base_data$immigrant_row <- which(compact_immigrant_matrix > 0, arr.ind = TRUE, useNames = FALSE)[,1]
+          nonzero_base_data$emigrant_row <- which(compact_emigrant_matrix > 0, arr.ind = TRUE, useNames = FALSE)[, 1]
+          nonzero_base_data$immigrant_row <- which(compact_immigrant_matrix > 0, arr.ind = TRUE, useNames = FALSE)[, 1]
           target_sorted_indices <- nonzero_base_data[order(nonzero_base_data$target_pop, nonzero_base_data$source_pop), c("target_pop", "source_pop")]
           nonzero_base_data$immigrant_row <- nonzero_base_data$immigrant_row[order(target_sorted_indices$source_pop, target_sorted_indices$target_pop)]
         } else {
@@ -352,26 +361,25 @@ DispersalGenerator <- R6Class("DispersalGenerator",
 
         # Calculate the sequential changes in dispersals when dispersal friction object is present
         if (!is.null(self$dispersal_friction) && !is.null(self$distance_data$changes) && nonzero_compact_rows) {
-
           # Calculate the initial dispersal data by applying the first (friction) distance changes to the (compact) base data
           compact_matrix[as.matrix(self$distance_data$changes[[1]][, c("compact_row", "source_pop")])] <-
-            dispersal_rate_classes[self$distance_data$changes[[1]]$distance_class]*multipliers[self$distance_data$changes[[1]]$source_pop]
+            dispersal_rate_classes[self$distance_data$changes[[1]]$distance_class] * multipliers[self$distance_data$changes[[1]]$source_pop]
 
           # Construct the dispersal data from the base (non-friction) data for the non-zero base indices (ensures all indices present for changes)
           self$dispersal_data <- list(data.frame(nonzero_base_data[, c("target_pop", "source_pop", "emigrant_row", "immigrant_row")],
-                                                 dispersal_rate = compact_matrix[compact_dispersal_indices]))
+            dispersal_rate = compact_matrix[compact_dispersal_indices]
+          ))
 
           # Round when required
           if (!is.null(self$decimals)) {
             self$dispersal_data[[1]]$dispersal_rate <- round(self$dispersal_data[[1]]$dispersal_rate, self$decimals)
-            compact_matrix <- compact_matrix*0 > 0 # all FALSE
+            compact_matrix <- compact_matrix * 0 > 0 # all FALSE
             compact_matrix[compact_dispersal_indices] <- TRUE # used to resolve decimal rounding in changes
           } else {
-            compact_matrix <- NULL  # release from memory
+            compact_matrix <- NULL # release from memory
           }
 
           if (type == "data") {
-
             # Map the original distance classes and the new emigrant and immigrant row indices via compact matrices
             original_distance_class_map <- emigrant_row_map <- immigrant_row_map <- array(NA, c(base_compact_rows, populations))
             original_distance_class_map[as.matrix(self$distance_data$base[, c("compact_row", "source_pop")])] <- self$distance_data$base$distance_class
@@ -380,34 +388,31 @@ DispersalGenerator <- R6Class("DispersalGenerator",
 
             # Calculate subsequent changes in dispersals
             for (i in 2:length(self$distance_data$changes)) {
-
               # Select data for non-zero dispersal classes
               original_distance_classes <- original_distance_class_map[as.matrix(self$distance_data$changes[[i]][, c("compact_row", "source_pop")])]
               nonzero_dispersal_indices <- which(original_distance_classes <= length(which(dispersal_rate_classes > 0)))
-              nonzero_change_data <- self$distance_data$changes[[i]][nonzero_dispersal_indices,]
+              nonzero_change_data <- self$distance_data$changes[[i]][nonzero_dispersal_indices, ]
 
               # Select rows that don't round to zero in the base data
               if (!is.null(self$decimals)) {
-                nonzero_change_data <- nonzero_change_data[which(compact_matrix[as.matrix(nonzero_change_data[, c("compact_row", "source_pop")])]),]
+                nonzero_change_data <- nonzero_change_data[which(compact_matrix[as.matrix(nonzero_change_data[, c("compact_row", "source_pop")])]), ]
               }
 
               # Calculate/construct dispersal rates using class and multiplier (based on non-friction data)
               self$dispersal_data[[i]] <- data.frame(nonzero_change_data[, c("target_pop", "source_pop")],
-                                                     emigrant_row = emigrant_row_map[as.matrix(nonzero_change_data[, c("compact_row", "source_pop")])],
-                                                     immigrant_row = immigrant_row_map[as.matrix(nonzero_change_data[, c("compact_row", "source_pop")])],
-                                                     dispersal_rate = dispersal_rate_classes[nonzero_change_data$distance_class]*multipliers[nonzero_change_data$source_pop])
+                emigrant_row = emigrant_row_map[as.matrix(nonzero_change_data[, c("compact_row", "source_pop")])],
+                immigrant_row = immigrant_row_map[as.matrix(nonzero_change_data[, c("compact_row", "source_pop")])],
+                dispersal_rate = dispersal_rate_classes[nonzero_change_data$distance_class] * multipliers[nonzero_change_data$source_pop]
+              )
               # Round when required
               if (!is.null(self$decimals) && length(self$dispersal_data[[i]]) > 0) {
                 self$dispersal_data[[i]]$dispersal_rate <- round(self$dispersal_data[[i]]$dispersal_rate, self$decimals)
               }
-
             }
-
           } else { # matrix
             self$dispersal_matrix <- array(0, c(populations, populations))
             self$dispersal_matrix[as.matrix(self$dispersal_data[[1]][, c("target_pop", "source_pop")])] <- self$dispersal_data[[1]]$dispersal_rate
           }
-
         } else { # no dispersal friction object
 
           # Set dispersals from non-zero dispersal data
@@ -417,14 +422,11 @@ DispersalGenerator <- R6Class("DispersalGenerator",
           } else {
             self$dispersal_data <- list(nonzero_base_data[, c("target_pop", "source_pop", "emigrant_row", "immigrant_row", "dispersal_rate")])
           }
-
         }
-
       } else {
         return("Dispersal calculation requires sample parameter settings for proportion, breadth & maximum distance (look-up data may be missing)")
       }
     }
-
   ), # end public
 
   private = list(
@@ -432,8 +434,10 @@ DispersalGenerator <- R6Class("DispersalGenerator",
     ## Attributes ##
 
     # Model attributes #
-    .model_attributes = c("region", "coordinates", "dispersal_proportion", "dispersal_breadth", "dispersal_max_distance",
-                          "dispersal_index", "dispersal_matrix", "dispersal_data"),
+    .model_attributes = c(
+      "region", "coordinates", "dispersal_proportion", "dispersal_breadth", "dispersal_max_distance",
+      "dispersal_index", "dispersal_matrix", "dispersal_data"
+    ),
     .region = NULL,
     .dispersal_proportion = NULL,
     .dispersal_breadth = NULL,
@@ -443,12 +447,14 @@ DispersalGenerator <- R6Class("DispersalGenerator",
     .dispersal_data = NULL,
 
     # Attributes accessible via model get/set methods #
-    .active_attributes = c("region", "coordinates", "description", "inputs", "outputs", "file_templates", "function_templates",
-                           "distribution_templates", "uses_correlations", "spatial_correlation", "temporal_correlation",
-                           "time_steps", "decimals", "occupancy_mask", "template_attached", "dispersal_friction",
-                           "distance_classes", "distance_scale", "distance_data", "dispersal_function_data",
-                           "dispersal_proportion", "dispersal_breadth", "dispersal_max_distance", "dispersal_index",
-                           "dispersal_matrix", "dispersal_data")
+    .active_attributes = c(
+      "region", "coordinates", "description", "inputs", "outputs", "file_templates", "function_templates",
+      "distribution_templates", "uses_correlations", "spatial_correlation", "temporal_correlation",
+      "time_steps", "decimals", "occupancy_mask", "template_attached", "dispersal_friction",
+      "distance_classes", "distance_scale", "distance_data", "dispersal_function_data",
+      "dispersal_proportion", "dispersal_breadth", "dispersal_max_distance", "dispersal_index",
+      "dispersal_matrix", "dispersal_data"
+    )
 
     # Dynamic attributes #
     # .attribute_aliases       [inherited]
@@ -460,7 +466,6 @@ DispersalGenerator <- R6Class("DispersalGenerator",
     # Errors and warnings #
     # .error_messages          [inherited]
     # .warning_messages        [inherited]
-
   ), # end private
 
   # Active binding accessors for private attributes (above and template nested) #
@@ -625,20 +630,20 @@ DispersalGenerator <- R6Class("DispersalGenerator",
           # Protect consistency of existing distance data associated with an existing dispersal friction object
           if (!is.null(self$distance_data) && !is.null(self$dispersal_friction)) {
             stop("Dispersal generator distance data is already associated with the existing dispersal friction object", call. = FALSE)
-          # Check region/coordinates consistency
+            # Check region/coordinates consistency
           } else if (!is.null(value$region) && !is.null(self$region) &&
-                     (value$region$region_cells != self$region$region_cells ||
-                      !all(value$coordinates == self$coordinates) ||
-                      (self$region$use_raster && !self$region$raster_is_consistent(value$region$region_raster)))) {
+            (value$region$region_cells != self$region$region_cells ||
+              !all(value$coordinates == self$coordinates) ||
+              (self$region$use_raster && !self$region$raster_is_consistent(value$region$region_raster)))) {
             stop("Dispersal friction object is inconsistent with the dispersal generator region/coordinates", call. = FALSE)
           } else if (is.null(value$region) && !is.null(self$region) && !is.null(value$conductance) &&
-                     any(class(value$conductance) %in% c("RasterLayer", "RasterStack", "RasterBrick")) &&
-                     (self$region$use_raster && !self$region$raster_is_consistent(value$conductance) ||
-                      !self$region$use_raster)) {
+            any(class(value$conductance) %in% c("RasterLayer", "RasterStack", "RasterBrick")) &&
+            (self$region$use_raster && !self$region$raster_is_consistent(value$conductance) ||
+              !self$region$use_raster)) {
             stop("Conductance raster is inconsistent with the dispersal generator region", call. = FALSE)
           } else if (is.null(value$region) && !is.null(self$region) && !is.null(value$conductance) &&
-                     is.matrix(value$conductance) &&
-                     nrow(value$conductance) != self$region$region_cells) {
+            is.matrix(value$conductance) &&
+            nrow(value$conductance) != self$region$region_cells) {
             stop("Conductance matrix dimensions are inconsistent with the dispersal generator region/coordinates ", call. = FALSE)
           } else if (!is.null(self$distance_data)) {
             # Existing distance data will lack temporal changes
@@ -666,7 +671,7 @@ DispersalGenerator <- R6Class("DispersalGenerator",
       if (missing(value)) {
         if (is.null(self$generative_template$distance_classes) && is.numeric(self$dispersal_max_distance)) {
           # Use max distance to generate classes (up to 1000|max_distance_classes)
-          seq_step <- max(trunc(self$dispersal_max_distance/self$max_distance_classes), 1)
+          seq_step <- max(trunc(self$dispersal_max_distance / self$max_distance_classes), 1)
           self$generative_template$distance_classes <- seq(seq_step, self$dispersal_max_distance, seq_step)
         }
         self$generative_template$distance_classes
@@ -752,7 +757,7 @@ DispersalGenerator <- R6Class("DispersalGenerator",
     dispersal_breadth = function(value) {
       if (missing(value)) {
         if (!is.null(self$dispersal_function_data) && !is.null(self$dispersal_index) &&
-            any(self$get_attribute_aliases("dispersal_breadth") %in% names(self$dispersal_function_data))) {
+          any(self$get_attribute_aliases("dispersal_breadth") %in% names(self$dispersal_function_data))) {
           # Use function look-up data
           function_data_column <- which(names(self$dispersal_function_data) %in% self$get_attribute_aliases("dispersal_breadth"))
           self$dispersal_function_data[[function_data_column]][self$dispersal_index]
@@ -776,12 +781,12 @@ DispersalGenerator <- R6Class("DispersalGenerator",
     dispersal_max_distance = function(value) {
       if (missing(value)) {
         if (!is.null(self$dispersal_function_data) && !is.null(self$dispersal_index) &&
-            any(names(self$dispersal_function_data) %in% self$get_attribute_aliases("dispersal_max_distance"))) {
+          any(names(self$dispersal_function_data) %in% self$get_attribute_aliases("dispersal_max_distance"))) {
           # Use function look-up data
           function_data_column <- which(names(self$dispersal_function_data) %in% self$get_attribute_aliases("dispersal_max_distance"))
           self$dispersal_function_data[[function_data_column]][self$dispersal_index]
         } else if (is.null(private$.dispersal_max_distance) && is.null(self$generative_template$dispersal_max_distance) &&
-                   is.numeric(self$distance_classes)) {
+          is.numeric(self$distance_classes)) {
           max(self$distance_classes)
         } else {
           if (any(self$get_attribute_aliases("dispersal_max_distance") %in% self$inputs)) {
@@ -821,7 +826,7 @@ DispersalGenerator <- R6Class("DispersalGenerator",
       } else {
         private$.dispersal_index <- value
         if (is.numeric(value) && !is.null(self$dispersal_function_data)) {
-          parameter_values <- as.list(self$dispersal_function_data[value,])
+          parameter_values <- as.list(self$dispersal_function_data[value, ])
           self$set_attributes(parameter_values)
         }
       }
@@ -921,6 +926,5 @@ DispersalGenerator <- R6Class("DispersalGenerator",
         super$warning_messages <- value
       }
     }
-
   ) # end active
 )
