@@ -6,37 +6,44 @@
 #' \code{\link{Generator}} outputs.
 #'
 #' @examples
-#' \dontrun{
 #' # U Island example region
-#' coordinates <- data.frame(x = rep(seq(177.01, 177.05, 0.01), 5),
-#'                           y = rep(seq(-18.01, -18.05, -0.01), each = 5))
+#' coordinates <- data.frame(
+#'   x = rep(seq(177.01, 177.05, 0.01), 5),
+#'   y = rep(seq(-18.01, -18.05, -0.01), each = 5)
+#' )
 #' template_raster <- Region$new(coordinates = coordinates)$region_raster # full extent
 #' template_raster[][-c(7, 9, 12, 14, 17:19)] <- NA # make U Island
 #' region <- Region$new(template_raster = template_raster)
-#' raster::plot(region$region_raster, main = "Example region (indices)",
-#'              xlab = "Longitude (degrees)", ylab = "Latitude (degrees)",
-#'              colNA = "blue")
+#' raster::plot(region$region_raster,
+#'   main = "Example region (indices)",
+#'   xlab = "Longitude (degrees)", ylab = "Latitude (degrees)",
+#'   colNA = "blue"
+#' )
 #' # Sample results occupancy (ignore cell 2 in last 3 time steps)
 #' occupancy_raster <- region$raster_from_values(array(1, c(7, 13)))
 #' occupancy_raster[region$region_indices][2, 11:13] <- 0
 #' occupancy_raster[region$region_indices]
 #' # Simulation example results
 #' example_results <- list(abundance = region$raster_from_values(
-#'   t(apply(matrix(11:17), 1,
-#'           function(n) c(rep(n, 3), round(n*exp(-(0:9)/log(n))))))))
+#'   t(apply(
+#'     matrix(11:17), 1,
+#'     function(n) c(rep(n, 3), round(n * exp(-(0:9) / log(n))))
+#'   ))
+#' ))
 #' example_results$abundance[region$region_indices]
 #' # Simulation results object
-#' sim_results <- SimulationResults$new(region = region,
-#'                                      time_steps = 13,
-#'                                      burn_in_steps = 3,
-#'                                      occupancy_mask = occupancy_raster)
+#' sim_results <- SimulationResults$new(
+#'   region = region,
+#'   time_steps = 13,
+#'   burn_in_steps = 3,
+#'   occupancy_mask = occupancy_raster
+#' )
 #' # Clone (for each simulation results)
 #' results_clone <- sim_results$new_clone(results = example_results)
 #' results_clone$get_attribute("abundance")
 #' results_clone$get_attribute("abundance")[region$region_indices]
 #' results_clone$all$get_attribute("abundance")
 #' results_clone$get_attribute("all$abundance")
-#' }
 #'
 #' @importFrom R6 R6Class
 #' @include SpatialModel.R
@@ -69,8 +76,8 @@ SimulationResults <- R6Class("SimulationResults",
     initialize = function(results = NULL, parent = NULL, ...) {
       if (!is.null(results)) {
         if (is.character(results) && file.exists(results)) {
-          results = readRDS(results)
-        } else  if (is.character(results)) {
+          results <- readRDS(results)
+        } else if (is.character(results)) {
           stop(paste("Could not read results from", results), call. = FALSE)
         }
         if (!is.list(results)) {
@@ -99,8 +106,10 @@ SimulationResults <- R6Class("SimulationResults",
       if ("parent" %in% names(list(...))) {
         super$new_clone(...)
       } else {
-        super$new_clone(time_steps = self$time_steps, burn_in_steps = self$burn_in_steps,
-                        occupancy_mask = self$occupancy_mask, default = self$default, ...)
+        super$new_clone(
+          time_steps = self$time_steps, burn_in_steps = self$burn_in_steps,
+          occupancy_mask = self$occupancy_mask, default = self$default, ...
+        )
       }
     },
 
@@ -152,8 +161,8 @@ SimulationResults <- R6Class("SimulationResults",
               if (is.null(self$parent) && !is.null(self$occupancy_mask)) {
                 if (nrow(as.matrix(attribute_list[[param]][])) == nrow(as.matrix(self$occupancy_mask[]))) {
                   if (ncol(as.matrix(self$occupancy_mask[])) %in% c(1, ncol(as.matrix(attribute_list[[param]][])))) {
-                    attribute_list[[param]][] <- as.matrix(attribute_list[[param]][]*self$occupancy_mask[])
-                  } else if (ncol(as.matrix(attribute_list[[param]][])) > 1)  {
+                    attribute_list[[param]][] <- as.matrix(attribute_list[[param]][] * self$occupancy_mask[])
+                  } else if (ncol(as.matrix(attribute_list[[param]][])) > 1) {
                     self$error_messages <- sprintf("The column/layer dimension of the occupancy mask and the %s result are inconsistent", param)
                   }
                 } else if (is.matrix(attribute_list[[param]][])) {
@@ -180,8 +189,8 @@ SimulationResults <- R6Class("SimulationResults",
                   occupancy_mask <- self$occupancy_mask
                 }
                 if ((is.null(self$time_steps) && (is.null(occupancy_mask) || ncol(as.matrix(occupancy_mask[])) == 1)) ||
-                    (is.numeric(self$time_steps) && length(attribute_list[[param]]) == self$time_steps) ||
-                    (is.numeric(occupancy_mask[]) && length(attribute_list[[param]]) == ncol(as.matrix(occupancy_mask[])))) {
+                  (is.numeric(self$time_steps) && length(attribute_list[[param]]) == self$time_steps) ||
+                  (is.numeric(occupancy_mask[]) && length(attribute_list[[param]]) == ncol(as.matrix(occupancy_mask[])))) {
                   if (length(attribute_list[[param]]) > self$burn_in_steps) {
                     duration_indices <- (self$burn_in_steps + 1):length(attribute_list[[param]])
                     attribute_list[[param]] <- attribute_list[[param]][duration_indices]
@@ -214,7 +223,7 @@ SimulationResults <- R6Class("SimulationResults",
               params[[param]] <- NULL
             }
           } else if (is.numeric(params[[param]]) && !is.null(self$region) && self$region$use_raster &&
-                     nrow(as.matrix(params[[param]])) == self$region$region_cells) {
+            nrow(as.matrix(params[[param]])) == self$region$region_cells) {
             self$error_messages <- sprintf("The %s result must be a raster layer, stack or brick (consistent with the defined region)", param)
             params[[param]] <- NULL
           }
@@ -224,7 +233,6 @@ SimulationResults <- R6Class("SimulationResults",
     }
 
     # New methods (see active attributes) #
-
   ), # end public
 
   private = list(
@@ -252,7 +260,6 @@ SimulationResults <- R6Class("SimulationResults",
     # Errors and warnings #
     # .error_messages    [inherited]
     # .warning_messages  [inherited]
-
   ), # end private
 
   # Active binding accessors for private attributes (above) #
@@ -422,6 +429,5 @@ SimulationResults <- R6Class("SimulationResults",
         super$warning_messages <- value
       }
     }
-
   ) # end active
 )
